@@ -1,16 +1,16 @@
 package Workflow::Context;
 
-# $Id: Context.pm,v 1.3 2004/03/08 04:56:09 cwinters Exp $
+# $Id: Context.pm,v 1.4 2006/07/07 21:24:52 jonasbn Exp $
 
 use strict;
 use base qw( Workflow::Base );
 
-$Workflow::Context::VERSION  = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
+$Workflow::Context::VERSION  = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 
 sub merge {
     my ( $self, $other ) = @_;
     my $other_params = $other->param();
-    while ( my ( $k, $v ) = keys %{ $other_params } ) {
+    while ( my ( $k, $v ) = each %{ $other_params } ) {
         $self->param( $k, $v );
     }
 }
@@ -65,11 +65,13 @@ L<Workflow>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2004 Chris Winters. All rights reserved.
+Copyright (c) 2003-2006 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
+Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt>, current maintainer.
+
+Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
